import { join, normalize } from 'node:path';
import { rmSync } from 'node:fs';
import logger from '@wdio/logger';
import { defaultOptions } from './helpers/options.js';
import { FOLDERS } from './helpers/constants.js';
const log = logger('@wdio/visual-service:webdriver-image-comparison');
export default class BaseClass {
    defaultOptions;
    folders;
    constructor(options) {
        // determine default options
        this.defaultOptions = defaultOptions(options);
        const baselineFolder = typeof options.baselineFolder === 'function'
            ? options.baselineFolder(options)
            : normalize(options.baselineFolder || FOLDERS.DEFAULT.BASE);
        const baseFolder = typeof options.screenshotPath === 'function'
            ? options.screenshotPath(options)
            : normalize(options.screenshotPath || FOLDERS.DEFAULT.SCREENSHOTS);
        this.folders = {
            actualFolder: join(baseFolder, FOLDERS.ACTUAL),
            baselineFolder,
            diffFolder: join(baseFolder, FOLDERS.DIFF),
        };
        if (options.clearRuntimeFolder) {
            log.info('\x1b[33m\n##############################\n!!CLEARING!!\n##############################\x1b[0m');
            rmSync(this.folders.actualFolder, { recursive: true, force: true });
            rmSync(this.folders.diffFolder, { recursive: true, force: true });
        }
    }
}
